<?php

use yii\db\Migration;

class m130524_201442_init extends Migration
{
    public function up()
    {
        $tableOptions = null;
        if ($this->db->driverName === 'mysql') {
            // http://stackoverflow.com/questions/766809/whats-the-difference-between-utf8-general-ci-and-utf8-unicode-ci
            $tableOptions = 'CHARACTER SET utf8 COLLATE utf8_unicode_ci ENGINE=InnoDB';
        }

        $this->createTable('{{%user}}', [
            'id' => $this->primaryKey(),
            'username' => $this->string()->notNull()->unique(),
            'auth_key' => $this->string(32)->notNull(),
            'password_hash' => $this->string()->notNull(),
            'password_reset_token' => $this->string()->unique(),
            'email' => $this->string()->notNull()->unique(),
            'avatar' => $this->string()->defaultValue(''),
            'status' => $this->smallInteger()->notNull()->defaultValue(10),
            'created_at' => $this->integer()->notNull(),
            'updated_at' => $this->integer()->notNull(),
        ], $tableOptions);
        $this->batchInsert("{{%user}}", ['id','username','auth_key','password_hash','email','status','created_at','updated_at',],
            [
                [
                    '1',
                    'aaa',
                    'y-I4ci4glWqom_ZeW6IItOCWFx69FjqQ',
                    '$2y$13$h2GSh/y8qa1WU.ZRVU3VaOr2/Zfh/VxCUfLmbY4xNeZ1Ql2lbMF36',
                    'aaa@feehi.com',
                    '10',
                    '1469070407',
                    '0',
                ],
                [
                    '2',
                    'bbb',
                    '9wMhzQEqGW8h1_NFBoCYY3StQ_ZJ8UaM',
                    '$2y$13$MbDa4j1TujVid9Zk0saOYu7eGk/N52nOJjTYr22dCYRhJ/D9jV29.',
                    'bbb@feehi.com',
                    '10',
                    '1469070568',
                    '0',
                ],
            ]
        );

        $this->createTable('{{%admin_user}}', [
            'id' => $this->primaryKey()->unsigned(),
            'username' => $this->string()->notNull()->unique(),
            'auth_key' => $this->string(32)->notNull(),
            'password_hash' => $this->string()->notNull(),
            'password_reset_token' => $this->string()->unique(),
            'email' => $this->string()->notNull()->unique(),
            'avatar' => $this->string()->defaultValue(''),
            'status' => $this->smallInteger()->notNull()->defaultValue(10),
            'created_at' => $this->integer()->notNull(),
            'updated_at' => $this->integer()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert("{{%admin_user}}", ['id','username','auth_key','password_hash','email','avatar','status','created_at','updated_at'],
            [
                [
                    '1',
                    'admin',
                    'zr9mY7lt23oAhj_ZYjydbLJKcbE3FJ19',
                    '$2y$13$8aF72c/7Nqq/atyMivhVTej0bIXS1t8daPJXKtVjFzJUsG68eGgaG',
                    'admin@feehi.com',
                    '',
                    '10',
                    '1468288038',
                    '0',
                ],
                [
                    '2',
                    'fff',
                    '1JC2paBZhxrLPXNEpGDqW8Bp130x0_g6',
                    '$2y$13$v.WxC/zKWasDR2fVZsa5u.xoVCh.8VE1QtyqCQNFrZO7DgEvZoZhS',
                    'fff@feehi.com',
                    '',
                    '10',
                    '1469087451',
                    '0',
                ],
            ]
        );

        $this->createTable('{{%admin_log}}', [
            'id' => $this->primaryKey()->unsigned(),
            'user_id' => $this->integer()->unsigned()->notNull(),
            'route' => $this->string()->defaultValue(''),
            'description' => $this->text(),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->addForeignKey('fk_user_id', "{{%admin_log}}", "user_id", "{{admin_user}}", "id", "CASCADE", "CASCADE");


        $this->createTable('{{%admin_role_user}}', [
            'id' => $this->primaryKey()->unsigned(),
            'uid' => $this->integer()->unsigned()->notNull(),
            'role_id' => $this->integer()->unsigned()->notNull(),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->addForeignKey('fk_uid', "{{%admin_role_user}}", "uid", "{{%admin_user}}", "id", "CASCADE", "CASCADE");

        $this->createTable('{{%admin_roles}}', [
            'id' => $this->primaryKey()->unsigned(),
            'parent_id' => $this->integer()->unsigned()->defaultValue(0),
            'role_name' => $this->string()->notNull(),
            'remark' => $this->string()->defaultValue(''),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert("{{%admin_roles}}", ['id','parent_id','role_name','created_at','updated_at','remark'],
            [
                [
                    '1',
                    '0',
                    '超级管理员',
                    '1468309347',
                    '0',
                    '拥有所有权限',
                ],
                [
                    '2',
                    '0',
                    '编辑',
                    '1468309363',
                    '1469070673',
                    '拥有seo设置，文章添加、修改、编辑、删除的权限',
                ],
            ]
        );

        $this->createTable('{{%category}}', [
            'id' => $this->primaryKey()->unsigned(),
            'parent_id' => $this->integer()->unsigned()->defaultValue(0),
            'name' => $this->string()->notNull(),
            'sort' => $this->integer()->unsigned()->defaultValue(0),
            'remark' => $this->string()->defaultValue(''),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert("{{%category}}", ['id','parent_id','name','sort','created_at','updated_at','remark'],
            [
                [
                    '1',
                    '0',
                    'php',
                    '0',
                    '1468293958',
                    '0',
                    '',
                ],
                [
                    '2',
                    '0',
                    'java',
                    '0',
                    '1468293965',
                    '0',
                    '',
                ],
                [
                    '3',
                    '0',
                    'javascript',
                    '0',
                    '1468293974',
                    '0',
                    '',
                ],
            ]
        );

        $this->createTable('{{%article}}', [
            'id' => $this->primaryKey()->unsigned(),
            'cid' => $this->integer()->unsigned()->defaultValue(0),
            'type' => $this->integer()->unsigned()->defaultValue(0),
            'title' => $this->string()->notNull(),
            'sub_title' => $this->string()->defaultValue(''),
            'summary' => $this->string()->defaultValue(''),
            'thumb' => $this->string()->defaultValue(''),
            'seo_title' => $this->string()->defaultValue(''),
            'seo_keywords' => $this->string()->defaultValue(''),
            'seo_description' => $this->string()->defaultValue(''),
            'status' => $this->smallInteger()->unsigned()->defaultValue(1),
            'sort' => $this->integer()->unsigned()->defaultValue(0),
            'author_id' => $this->integer()->unsigned()->defaultValue(0),
            'author_name' => $this->string()->defaultValue(''),
            'scan_count' => $this->integer()->unsigned()->defaultValue(0),
            'comment_count' => $this->integer()->unsigned()->defaultValue(0),
            'can_comment' => $this->smallInteger()->unsigned()->defaultValue(1),
            'visibility' => $this->smallInteger()->unsigned()->defaultValue(1),
            'tag' => $this->string()->defaultValue(''),
            'flag_headline' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_recommend' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_slide_show' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_special_recommend' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_roll' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_bold' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_picture' => $this->smallInteger()->unsigned()->defaultValue(0),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
       // $this->addForeignKey("fk_cid", "{{%article}}", "cid", "{{%category}}", "id", "CASCADE", "CASCADE");
        $this->createIndex("index_title", "{{%article}}",['title', 'cid', 'tag']);
        $this->batchInsert("{{%article}}",[
            'id','cid','type','title','sub_title','summary','thumb','seo_title','seo_keywords','seo_description','status','sort','author_id','author_name','scan_count','comment_count','can_comment','visibility','tag','flag_headline','flag_recommend','flag_slide_show','flag_special_recommend','flag_roll','flag_bold','flag_picture','created_at','updated_at'] ,
            [
                [
                    '1',
                    '3',
                    '0',
                    '高效快速地加载 AngularJS 视图',
                    '',
                    '当AngularJS应用程序变大时，很多问题就开始显现出来了，比如多层级视图的加载问题，如果在子视图显示之前没有预加载，则可能在需要展示时，发生视觉闪烁的情况。这种问题在网络缓慢，或者服务器使用较慢的https连接时更容易出现。',
                    '###~SITEURL~###/uploads/article/thumb/2016071211354628.jpg',
                    '高效快速地加载 AngularJS 视图',
                    'JavaScript, AngularJS',
                    '当AngularJS应用程序变大时，很多问题就开始显现出来了，比如多层级视图的加载问题，如果在子视图显示之前没有预加载，则可能在需要展示时，发生视觉闪烁的情况。这种问题在网络缓慢，或者服务器使用较慢的https连接时更容易出现。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'JavaScript,AngularJS',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468294546',
                    '1468294568',
                ],
                [
                    '2',
                    '3',
                    '0',
                    '如何定位 Node.js 的内存泄漏',
                    '',
                    '在 《一次 Node.js 应用内存暴涨分析》中，我们处理了一个 Node.js vm 引发的内存泄漏问题，处理过程也是比较艰辛。而在我们实际开发中，可能经常会碰到内存泄漏的问题，但很多情况下，我们对于这种问题的处理是有些迷茫的，没有一定的操作流程，效率比较低。虽然这种问题对于经验的要求比较高，但如果有一个简单的排查流程，还是会有一定帮助的。',
                    '###~SITEURL~###/uploads/article/thumb/201607121141407.png',
                    '',
                    '',
                    '在 《一次 Node.js 应用内存暴涨分析》中，我们处理了一个 Node.js vm 引发的内存泄漏问题，处理过程也是比较艰辛。而在我们实际开发中，可能经常会碰到内存泄漏的问题，但很多情况下，我们对于这种问题的处理是有些迷茫的，没有一定的操作流程，效率比较低。虽然这种问题对于经验的要求比较高，但如果有一个简单的排查流程，还是会有一定帮助的。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '3',
                    '0',
                    '1',
                    '0',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '1468294900',
                    '1468301331',
                ],
                [
                    '3',
                    '1',
                    '0',
                    'Hack：用于HHVM的一种新编程语言',
                    '',
                    '',
                    '###~SITEURL~###/uploads/article/thumb/2016071212382956.jpg',
                    '',
                    'Facebook, hack, php',
                    '',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'Facebook, hack, php',
                    '0',
                    '0',
                    '0',
                    '1',
                    '1',
                    '0',
                    '0',
                    '1468298309',
                    '1468301305',
                ],
                [
                    '4',
                    '3',
                    '0',
                    '抛弃jQuery，拥抱原生JavaScript',
                    '',
                    '原生javascript',
                    '###~SITEURL~###/uploads/article/thumb/2016071212414099.png',
                    '抛弃jQuery，拥抱原生JavaScript',
                    'jquery,javascript,web',
                    '',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468298500',
                    '0',
                ],
                [
                    '5',
                    '2',
                    '0',
                    '[JAVA · 初级]：GC-垃圾回收机制',
                    '',
                    '在C++中，对象所占的内存在程序结束运行之前一直被占用，在明确释放之前不能分配给其它对象；而在Java中，当没有对象引用指向原先分配给某个对象的内存时，该内存便成为垃圾。',
                    '###~SITEURL~###/uploads/article/thumb/2016071212441669.jpg',
                    '[JAVA · 初级]：GC-垃圾回收机制',
                    'gc,垃圾回收,java',
                    '在C++中，对象所占的内存在程序结束运行之前一直被占用，在明确释放之前不能分配给其它对象；而在Java中，当没有对象引用指向原先分配给某个对象的内存时，该内存便成为垃圾。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'gc,垃圾回收,java',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468298628',
                    '1468299738',
                ],
                [
                    '6',
                    '1',
                    '0',
                    'PHP 7.0.2正式版发布：WordPress速度提升3倍！',
                    '',
                    '提到PHP，肯定会有人说这是世界上最好的编程语言。',
                    '###~SITEURL~###/uploads/article/thumb/2016071212472374.jpeg',
                    'PHP 7.0.2正式版发布：WordPress速度提升3倍！',
                    'php7,php,wordpress',
                    '提到PHP，肯定会有人说这是世界上最好的编程语言。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    'php7,php,wordpress',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468298843',
                    '0',
                ],
                [
                    '7',
                    '3',
                    '0',
                    '为何要学HTML5开发?HTML5发展前景如何？',
                    '',
                    '',
                    '',
                    '为何要学HTML5开发?HTML5发展前景如何？',
                    'html,html5',
                    '',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468298894',
                    '1468298938',
                ],
                [
                    '8',
                    '2',
                    '0',
                    'Spring知识点提炼',
                    '',
                    'spring框架',
                    '###~SITEURL~###/uploads/article/thumb/2016071212525610.jpg',
                    'Spring知识点提炼',
                    'spring,java',
                    'spring框架',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'spring,java',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '1468299176',
                    '1468301374',
                ],
                [
                    '9',
                    '3',
                    '0',
                    'CSS代码重构与优化之路',
                    '',
                    '着项目规模的增加，项目中的CSS代码也会越来越多，如果没有及时对CSS代码进行维护，CSS代码不断会越来越多。',
                    '###~SITEURL~###/uploads/article/thumb/2016071212553820.jpeg',
                    'CSS代码重构与优化之路',
                    'css,重构',
                    '着项目规模的增加，项目中的CSS代码也会越来越多，如果没有及时对CSS代码进行维护，CSS代码不断会越来越多。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'css,重构',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468299338',
                    '0',
                ],
                [
                    '10',
                    '1',
                    '0',
                    'PHP分页技术的代码和示例',
                    '',
                    '分页是目前在显示大量结果时所采用的最好的方式。',
                    '###~SITEURL~###/uploads/article/thumb/2016071212580919.png',
                    'PHP分页技术的代码和示例',
                    'php,分页,php分页',
                    '分页是目前在显示大量结果时所采用的最好的方式。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    'php,分页',
                    '0',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '0',
                    '1468299489',
                    '1468301281',
                ],
                [
                    '11',
                    '1',
                    '0',
                    '10个免费下载PHP脚本的网站',
                    '',
                    '免费的PHP脚本下载',
                    'http://cms.feehi.com/uploads/article/thumb/2016071213000120.png',
                    '10个免费下载PHP脚本的网站',
                    'php脚本,下载,代码下载',
                    '免费的PHP脚本下载',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '4',
                    '1',
                    '1',
                    '0',
                    'php脚本,下载,代码下载',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468299601',
                    '1468301148',
                ],
                [
                    '12',
                    '1',
                    '0',
                    '趣文：如果编程语言是女人（新编版）',
                    '',
                    '语言趣文',
                    '###~SITEURL~###/uploads/article/thumb/2016071213020658.png',
                    '趣文：如果编程语言是女人（新编版）',
                    'java, Javascript, Lisp, php, Python, Ruby, 编程语言, 趣文',
                    '语言趣文',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'java, Javascript, Lisp, php, Python, Ruby, 编程语言, 趣文',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '1468299726',
                    '1468301362',
                ],
                [
                    '13',
                    '3',
                    '0',
                    '浏览器缓存机制',
                    '',
                    '浏览器缓存机制，其实主要就是HTTP协议定义的缓存机制（如： Expires； Cache-control等）。',
                    '###~SITEURL~###/uploads/article/thumb/2016071213054793.jpg',
                    '浏览器缓存机制',
                    '缓存,浏览器缓存,http协议',
                    '浏览器缓存机制，其实主要就是HTTP协议定义的缓存机制（如： Expires； Cache-control等）。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    '缓存,浏览器缓存,http协议',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468299947',
                    '1468303626',
                ],
                [
                    '14',
                    '3',
                    '0',
                    'JavaScript 统治的世界，烤面包机将能运行 JS 了',
                    '',
                    '从浏览器到手机，从平板电脑到桌面电脑，从工业自动化到最小的微控制器——最近JavaScript 似乎蔓延到了最意想不到的地方，不远的将来，你的烤面包机也将会运行 JavaScript ……。但是为什么？',
                    '',
                    'JavaScript 统治的世界，烤面包机将能运行 JS 了',
                    'javascript,流行',
                    '从浏览器到手机，从平板电脑到桌面电脑，从工业自动化到最小的微控制器——最近JavaScript 似乎蔓延到了最意想不到的地方，不远的将来，你的烤面包机也将会运行 JavaScript ……。但是为什么？',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    'javascript,流行',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300042',
                    '0',
                ],
                [
                    '15',
                    '2',
                    '0',
                    '给Java说句公道话',
                    '',
                    '有些人问我，在现有的语言里面，有什么好的推荐？我说：“Java。” 他们很惊讶：“什么？Java！” 所以我现在来解释一下。',
                    '###~SITEURL~###/uploads/article/thumb/2016071213095350.jpg',
                    '给Java说句公道话',
                    'java',
                    '有些人问我，在现有的语言里面，有什么好的推荐？我说：“Java。” 他们很惊讶：“什么？Java！” 所以我现在来解释一下。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'java',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300193',
                    '1468301238',
                ],
                [
                    '16',
                    '2',
                    '0',
                    'Java编程入门（1.6）：现代用户界面',
                    '',
                    '算机刚问世时，普通人——包括大多数程序员——都不允许靠近计算机。',
                    '###~SITEURL~###/uploads/article/thumb/2016071214100948.jpg',
                    'Java编程入门（1.6）：现代用户界面',
                    'java,用户界面',
                    '算机刚问世时，普通人——包括大多数程序员——都不允许靠近计算机。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    'java,用户界面',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300356',
                    '1468303809',
                ],
                [
                    '17',
                    '3',
                    '0',
                    '精简页面的样式文件，去掉不用的样式',
                    '',
                    '精简css样式',
                    '',
                    '精简页面的样式文件，去掉不用的样式',
                    'css,样式',
                    '精简css样式',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '6',
                    '2',
                    '1',
                    '0',
                    'css,样式',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300509',
                    '0',
                ],
                [
                    '18',
                    '2',
                    '0',
                    'Java编程入门：前言',
                    '',
                    'Java编程入门》是一本使用Java作为入门语言的免费计算机编程课本',
                    '###~SITEURL~###/uploads/article/thumb/2016071213165538.jpg',
                    'Java编程入门：前言',
                    'java,入门,编程书籍',
                    'Java编程入门》是一本使用Java作为入门语言的免费计算机编程课本',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'java,入门,编程书籍',
                    '0',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '0',
                    '1468300615',
                    '1468301270',
                ],
                [
                    '19',
                    '2',
                    '0',
                    'Java 8最快的垃圾搜集器是什么？',
                    '',
                    'OpenJDK 8 有多种 GC（Garbage Collector）算法，如 Parallel GC、CMS 和 G1。哪一个才是最快的呢？如果在 Java 9 中将 Java 8 默认的 GC 从 Parallel GC 改为 G1 （目前只是建议）将会怎么样呢？让我们对此进行基准测试。',
                    'http://cms.feehi.com/uploads/article/thumb/2016071213182356.jpg',
                    'Java 8最快的垃圾搜集器是什么？',
                    'java,java8,垃圾收集',
                    'OpenJDK 8 有多种 GC（Garbage Collector）算法，如 Parallel GC、CMS 和 G1。哪一个才是最快的呢？如果在 Java 9 中将 Java 8 默认的 GC 从 Parallel GC 改为 G1 （目前只是建议）将会怎么样呢？让我们对此进行基准测试。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '33',
                    '7',
                    '1',
                    '0',
                    'java,java8,垃圾收集',
                    '0',
                    '0',
                    '0',
                    '1',
                    '1',
                    '0',
                    '0',
                    '1468300703',
                    '1468301343',
                ],
                [
                    '20',
                    '2',
                    '0',
                    '使用Memcached改进Java企业级应用性能（1）：架构和设置',
                    '',
                    'Memcached由Danga Interactive开发，用来提升LiveJournal.com网站性能。Memcached分布式架构支持众多的社交网络应用，Twitter、Facebook还有Wikipedia。在接下来的两部分教程中，Sunil Patil介绍了Memcached分布式哈希表架构，以及利用它帮助你为数据驱动Java企业应用做数据缓存。',
                    '###~SITEURL~###/uploads/article/thumb/201607121325288.png',
                    '使用Memcached改进Java企业级应用性能（1）：架构和设置',
                    'java,memcached',
                    'Memcached由Danga Interactive开发，用来提升LiveJournal.com网站性能。Memcached分布式架构支持众多的社交网络应用，Twitter、Facebook还有Wikipedia。在接下来的两部分教程中，Sunil Patil介绍了Memcached分布式哈希表架构，以及利用它帮助你为数据驱动Java企业应用做数据缓存。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    'jvm,java',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300831',
                    '1468303452',
                ],
                [
                    '21',
                    '2',
                    '0',
                    'JVM的相关知识整理和学习',
                    '',
                    '诺依曼体系结构中，指出计算机处理的数据和指令都是二进制数，采用存储程序方式不加区分的存储在同一个存储器里，并且顺序执行，指令由操作码和地址码组成，操作码决定了操作类型和所操作的数的数字类型，地址码则指出地址码和操作数。',
                    '###~SITEURL~###/uploads/article/thumb/2016071213203123.jpg',
                    'JVM的相关知识整理和学习',
                    'jvm,java',
                    '诺依曼体系结构中，指出计算机处理的数据和指令都是二进制数，采用存储程序方式不加区分的存储在同一个存储器里，并且顺序执行，指令由操作码和地址码组成，操作码决定了操作类型和所操作的数的数字类型，地址码则指出地址码和操作数。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'jvm,java',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300831',
                    '1468300844',
                ],
                [
                    '22',
                    '2',
                    '0',
                    '关于Java集合的小抄',
                    '',
                    '在尽可能短的篇幅里，将所有集合与并发集合的特征，实现方式，性能捋一遍。适合所有”精通Java”其实还不那么自信的人阅读。',
                    '###~SITEURL~###/uploads/article/thumb/2016071213224495.jpg',
                    '关于Java集合的小抄',
                    'java,java集合',
                    '在尽可能短的篇幅里，将所有集合与并发集合的特征，实现方式，性能捋一遍。适合所有”精通Java”其实还不那么自信的人阅读。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'java,java集合',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300964',
                    '1468300981',
                ],
                [
                    '23',
                    '0',
                    '2',
                    '关于我们',
                    'about',
                    '',
                    '',
                    '',
                    '',
                    '',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468309252',
                    '0',
                ],
                [
                    '24',
                    '0',
                    '2',
                    '联系方式',
                    'contact',
                    '',
                    '',
                    '',
                    '',
                    '',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468309318',
                    '0',
                ],
                [
                    '25',
                    '0',
                    '0',
                    'dfdf',
                    'dfd',
                    'fsafsdfsdf',
                    '',
                    '',
                    '',
                    '',
                    '0',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468898361',
                    '1470111146',
                ],
            ]
        );

        $this->createTable('{{%article_content}}', [
            'id' => $this->primaryKey()->unsigned(),
            'aid' => $this->integer()->unsigned()->defaultValue(0),
            'content' => "LongText",
        ], $tableOptions);
        $this->addForeignKey('fk_aid', "{{%article_content}}", "aid", "{{%article}}", "id", "CASCADE", "CASCADE");
        $this->batchInsert("{{%article_content}}", ['id','aid','content'], require(__DIR__.'/article.php')
        );

        $this->createTable('{{%comment}}', [
            'id' => $this->primaryKey()->unsigned(),
            'aid' => $this->integer()->unsigned()->defaultValue(0),
            'uid' => $this->integer()->unsigned()->defaultValue(0),
            'reply_to' => $this->integer()->unsigned()->defaultValue(0),
            'nickname' => $this->string()->defaultValue('游客'),
            'email' => $this->string()->defaultValue(''),
            'website_url' => $this->string()->defaultValue(''),
            'content' => $this->string()->notNull(),
            'ip' => $this->string()->defaultValue(''),
            'status' => $this->smallInteger()->unsigned()->defaultValue(0),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);

        $this->createTable('{{%friend_link}}', [
            'id' => $this->primaryKey()->unsigned(),
            'name' => $this->string()->notNull(),
            'image' => $this->string()->defaultValue(''),
            'url' => $this->string()->defaultValue(''),
            'target' => $this->string()->defaultValue('_blank'),
            'sort' => $this->integer()->unsigned()->defaultValue(0),
            'status' => $this->smallInteger()->unsigned()->defaultValue(0),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert("{{friend_link}}", ['id','name','image','url','target','sort','status','created_at','updated_at'],
            [
                [
                    '1',
                    '飞嗨博客',
                    '',
                    'http://blog.feehi.com',
                    '_blank',
                    '0',
                    '1',
                    '1468303851',
                    '0',
                ],
                [
                    '2',
                    '飞嗨网',
                    '',
                    'http://www.feehi.com',
                    '_blank',
                    '0',
                    '1',
                    '1468303882',
                    '0',
                ],
                [
                    '3',
                    '36kr',
                    '',
                    'http://www.36kr.com',
                    '_blank',
                    '0',
                    '1',
                    '1468303902',
                    '0',
                ],
                [
                    '4',
                    '破晓电影',
                    '',
                    'http://www.poxiao.com',
                    '_blank',
                    '0',
                    '1',
                    '1468303938',
                    '0',
                ],
                [
                    '5',
                    '翠竹林主题',
                    '',
                    'http://www.cuizl.com/',
                    '_blank',
                    '0',
                    '1',
                    '1468303974',
                    '0',
                ],
            ]
        );

        $this->createTable('{{%menu}}', [
            'id' => $this->primaryKey()->unsigned(),
            'type' => $this->integer()->unsigned()->defaultValue(0),
            'parent_id' => $this->integer()->unsigned()->defaultValue(0),
            'name' => $this->string()->notNull(),
            'url' => $this->string()->notNull(),
            'icon' => $this->string()->defaultValue(''),
            'sort' => $this->integer()->unsigned()->defaultValue(0),
            'target' => $this->string()->defaultValue('_blank'),
            'is_absolute_url' => $this->smallInteger()->unsigned()->defaultValue(0),
            'is_display' => $this->smallInteger()->unsigned()->defaultValue(1),
            'method' => "enum('all','post','get') default 'all'",
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->createIndex("index_name", "{{%menu}}", "name");
        $this->createIndex("index_url", "{{%menu}}", "url");
        $this->createIndex("index_method", "{{%menu}}", "method");
        $this->batchInsert("{{%menu}}", [
        'id','type','parent_id','name','url','icon','sort','target','is_absolute_url','is_display','method','created_at','updated_at'
        ],
            [
                [
                    '1',
                    '0',
                    '0',
                    '设置',
                    'setting',
                    'fa fa fa-cogs',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470064425',
                    '0',
                ],
                [
                    '2',
                    '0',
                    '1',
                    '网站设置',
                    'setting/website',
                    '',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470064528',
                    '0',
                ],
                [
                    '3',
                    '0',
                    '1',
                    'seo设置',
                    'setting/seo',
                    '',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470064574',
                    '0',
                ],
                [
                    '4',
                    '0',
                    '1',
                    '自定义设置',
                    'setting/custom',
                    '',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470064600',
                    '0',
                ],
                [
                    '5',
                    '0',
                    '0',
                    '菜单',
                    'menu',
                    'fa fa fa-th-list',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470064761',
                    '0',
                ],
                [
                    '6',
                    '0',
                    '5',
                    '前台菜单',
                    'frontend-menu/index',
                    '',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470064785',
                    '0',
                ],
                [
                    '7',
                    '0',
                    '5',
                    '后台菜单',
                    'menu/index',
                    '',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470064803',
                    '0',
                ],
                [
                    '8',
                    '0',
                    '0',
                    '内容',
                    'article',
                    'fa fa fa-edit',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470064850',
                    '0',
                ],
                [
                    '9',
                    '0',
                    '8',
                    '文章',
                    'article/index',
                    '',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470065005',
                    '0',
                ],
                [
                    '10',
                    '0',
                    '8',
                    '评论',
                    'comment/index',
                    '',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470065043',
                    '0',
                ],
                [
                    '11',
                    '0',
                    '8',
                    '单页',
                    'page/index',
                    '',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470065084',
                    '0',
                ],
                [
                    '12',
                    '0',
                    '8',
                    '分类',
                    'category/index',
                    '',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470065111',
                    '0',
                ],
                [
                    '13',
                    '0',
                    '0',
                    '用户',
                    'user/index',
                    'fa fa-users',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470065584',
                    '0',
                ],
                [
                    '14',
                    '0',
                    '0',
                    '权限',
                    'rbac',
                    'fa fa-shield',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470065608',
                    '1470065728',
                ],
                [
                    '15',
                    '0',
                    '14',
                    '管理员',
                    'admin-user/index',
                    '',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470065672',
                    '0',
                ],
                [
                    '16',
                    '0',
                    '14',
                    '角色',
                    'admin-roles/index',
                    '',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470065689',
                    '0',
                ],
                [
                    '17',
                    '0',
                    '0',
                    '友情链接',
                    'friend-link/index',
                    'fa fa-link',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470065784',
                    '0',
                ],
                [
                    '18',
                    '0',
                    '0',
                    '日志',
                    'log/index',
                    'fa fa-history',
                    '0',
                    '_blank',
                    '0',
                    '1',
                    'all',
                    '1470065819',
                    '0',
                ],
                [
                    '19',
                    '1',
                    '0',
                    '首页',
                    '/',
                    '',
                    '0',
                    '_self',
                    '0',
                    '1',
                    'all',
                    '1470111187',
                    '0',
                ],
                [
                    '20',
                    '1',
                    '0',
                    'php',
                    'cat/php',
                    '',
                    '0',
                    '_self',
                    '0',
                    '1',
                    'all',
                    '1470111200',
                    '0',
                ],
                [
                    '21',
                    '1',
                    '0',
                    'java',
                    'cat/java',
                    '',
                    '0',
                    '_self',
                    '0',
                    '1',
                    'all',
                    '1470111209',
                    '0',
                ],
                [
                    '22',
                    '1',
                    '0',
                    'javascript',
                    'cat/javascript',
                    '',
                    '0',
                    '_self',
                    '0',
                    '1',
                    'all',
                    '1470111222',
                    '0',
                ],
            ]
        );

        $this->createTable('{{%admin_role_permission}}', [
            'id' => $this->primaryKey()->unsigned(),
            'role_id' => $this->integer()->unsigned()->notNull(),
            'menu_id' => $this->integer()->unsigned()->notNull(),
            'name' => $this->string()->notNull(),
            'url' => $this->string()->notNull(),
            'method' => "enum('all','post','get') default 'all'",
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->addForeignKey('fk_menu_id', "{{%admin_role_permission}}", "menu_id", "{{%menu}}", "id", "CASCADE", "CASCADE");
        $this->addForeignKey('fk_menu_name', "{{%admin_role_permission}}", "name", "{{%menu}}", "name", "CASCADE", "CASCADE");
        $this->addForeignKey('fk_url', "{{%admin_role_permission}}", "url", "{{%menu}}", "url", "CASCADE", "CASCADE");
        $this->addForeignKey('fk_method', "{{%admin_role_permission}}", "method", "{{%menu}}", "method", "CASCADE", "CASCADE");
        $this->addForeignKey('fk_role_id', "{{%admin_role_permission}}", "role_id", "{{%admin_roles}}", "id", "CASCADE", "CASCADE");
        $this->batchInsert("{{%admin_role_permission}}", ['id','role_id','menu_id','name','url', 'method', 'created_at','updated_at'],
            [
                [
                    '62',
                    '1',
                    '3',
                    'seo设置',
                    'setting/seo',
                    'all',
                    '1470069312',
                    '0',
                ],
                [
                    '68',
                    '1',
                    '9',
                    '文章',
                    'article/index',
                    'all',
                    '1470069312',
                    '0',
                ],
                [
                    '69',
                    '1',
                    '10',
                    '评论',
                    'comment/index',
                    'all',
                    '1470069312',
                    '0',
                ],
                [
                    '78',
                    '2',
                    '1',
                    '设置',
                    'setting',
                    'all',
                    '1470069344',
                    '0',
                ],
                [
                    '79',
                    '2',
                    '3',
                    'seo设置',
                    'setting/seo',
                    'all',
                    '1470069344',
                    '0',
                ],
                [
                    '80',
                    '2',
                    '8',
                    '内容',
                    'article',
                    'all',
                    '1470069344',
                    '0',
                ],
                [
                    '81',
                    '2',
                    '9',
                    '文章',
                    'article/index',
                    'all',
                    '1470069344',
                    '0',
                ],
                [
                    '82',
                    '2',
                    '10',
                    '评论',
                    'comment/index',
                    'all',
                    '1470069344',
                    '0',
                ],
            ]
        );

        $this->createTable('{{%options}}', [
            'id' => $this->primaryKey()->unsigned(),
            'type' => $this->integer()->unsigned()->defaultValue(0),
            'name' => $this->string()->notNull(),
            'value' => $this->text(),
            'input_type' => $this->smallInteger()->unsigned()->defaultValue(1),
            'autoload' => $this->smallInteger()->unsigned()->defaultValue(1),
            'tips' => $this->string()->defaultValue(''),
            'sort' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert(
            "{{%options}}",
            [
                'id','type','name','value','input_type','tips','autoload','sort'],
            [
                [
                    '1',
                    '0',
                    'seo_title',
                    'feehi cms',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '2',
                    '0',
                    'seo_keywords',
                    '飞嗨,cms,yii2,php,feehi cms',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '3',
                    '0',
                    'seo_description',
                    'Feehi CMS，最好的cms之一',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '4',
                    '0',
                    'website_title',
                    'Feehi CMS',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '5',
                    '0',
                    'website_description',
                    'Based on most popular php framework yii2',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '6',
                    '0',
                    'website_email',
                    'admin@feehi.com',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '7',
                    '0',
                    'website_language',
                    'zh-CN',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '8',
                    '0',
                    'website_icp',
                    '粤ICP备15018643号',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '9',
                    '0',
                    'website_statics_script',
                    '',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '10',
                    '0',
                    'website_status',
                    '1',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '11',
                    '0',
                    'website_comment',
                    '1',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '12',
                    '0',
                    'website_comment_need_verify',
                    '0',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '13',
                    '0',
                    'website_timezone',
                    'Asia/Shanghai',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '14',
                    '1',
                    'qq',
                    '1838889850',
                    '1',
                    'QQ号码',
                    '1',
                    '0',
                ],
            ]
        );
    }

    public function down()
    {
        $this->db->createCommand("set foreign_key_checks=0")->execute(); 
        $this->dropTable('{{%user}}');
	$this->dropTable('{{%admin_log}}');
	$this->dropTable('{{%admin_role_permission}}');
	$this->dropTable('{{%admin_role_user}}');
	$this->dropTable('{{%admin_roles}}');
	$this->dropTable('{{%admin_user}}');
	$this->dropTable('{{%article}}');
	$this->dropTable('{{%article_content}}');
	$this->dropTable('{{%category}}');
	$this->dropTable('{{%comment}}');
	$this->dropTable('{{%friend_link}}');
	$this->dropTable('{{%menu}}');
	//$this->dropTable('{{%migration}}');
	$this->dropTable('{{%options}}');
	$this->db->createCommand("set foreign_key_checks=1")->execute();
    }
}
